Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(367)

Unified Diff: third_party/WebKit/Source/platform/loader/fetch/FetchContext.h

Issue 2584423002: Loading: move core/fetch to platform/loader/fetch (Closed)
Patch Set: another try Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/loader/fetch/FetchContext.h
diff --git a/third_party/WebKit/Source/core/fetch/FetchContext.h b/third_party/WebKit/Source/platform/loader/fetch/FetchContext.h
similarity index 94%
rename from third_party/WebKit/Source/core/fetch/FetchContext.h
rename to third_party/WebKit/Source/platform/loader/fetch/FetchContext.h
index fbc9092c6c97db9627ac3281faf1a040f3a321ed..ffc6869eb58647e2242e800f4aa9c16df9579f6a 100644
--- a/third_party/WebKit/Source/core/fetch/FetchContext.h
+++ b/third_party/WebKit/Source/platform/loader/fetch/FetchContext.h
@@ -31,12 +31,12 @@
#ifndef FetchContext_h
#define FetchContext_h
-#include "core/CoreExport.h"
-#include "core/fetch/CachePolicy.h"
-#include "core/fetch/FetchInitiatorInfo.h"
-#include "core/fetch/FetchRequest.h"
-#include "core/fetch/Resource.h"
+#include "platform/PlatformExport.h"
#include "platform/heap/Handle.h"
+#include "platform/loader/fetch/CachePolicy.h"
+#include "platform/loader/fetch/FetchInitiatorInfo.h"
+#include "platform/loader/fetch/FetchRequest.h"
+#include "platform/loader/fetch/Resource.h"
#include "platform/network/ResourceLoadPriority.h"
#include "platform/network/ResourceRequest.h"
#include "wtf/Forward.h"
@@ -59,10 +59,10 @@ enum FetchResourceType { FetchMainResource, FetchSubresource };
// in response to events in the ResourceFetcher. The ResourceFetcher or its job
// class, ResourceLoader, may call the methods on a FetchContext.
//
-// Any processing that depends on core/ components outside core/fetch/ should
-// be implemented on a subclass of this interface, and then exposed to the
-// ResourceFetcher via this interface.
-class CORE_EXPORT FetchContext
+// Any processing that depends on components outside platform/loader/fetch/
+// should be implemented on a subclass of this interface, and then exposed to
+// the ResourceFetcher via this interface.
+class PLATFORM_EXPORT FetchContext
: public GarbageCollectedFinalized<FetchContext> {
WTF_MAKE_NONCOPYABLE(FetchContext);

Powered by Google App Engine
This is Rietveld 408576698